@@ -3,19 +3,21 @@ package Sah::PSchema::perl::modname;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-04'; # DATE
 our $DIST = 'Sah-PSchemas-Perl'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use warnings;
 
-sub get_args {
+sub meta {
     my $class = shift;
 
     return +{
         v => 1,
-        ns_prefix => {
-            schema => 'perl::modname*',
-            default => '',
+        args => {
+            ns_prefix => {
+                schema => 'perl::modname*',
+                default => '',
+            },
         },
     };
 }
@@ -44,7 +46,7 @@ Sah::PSchema::perl::modname - Perl module name (parameterized)
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::PSchema::perl::modname (from Perl distribution Sah-PSchemas-Perl), released on 2020-06-04.
+This document describes version 0.002 of Sah::PSchema::perl::modname (from Perl distribution Sah-PSchemas-Perl), released on 2020-06-04.
 
 =head1 DESCRIPTION
 
